@@ -25,39 +25,41 @@ from ctapipe.coordinates import CameraFrame
 from . import disp
 
 __all__ = [
-    'add_delta_t_key',
-    'alt_to_theta',
-    'az_to_phi',
-    'cal_cam_source_pos',
-    'camera_to_altaz',
-    'cartesian_to_polar',
-    'clip_alt',
-    'compute_alpha',
-    'compute_theta2',
-    'expand_tel_list',
-    'extract_source_position',
-    'filter_events',
-    'get_effective_time',
-    'get_event_pos_in_camera',
-    'impute_pointing',
-    'linear_imputer',
-    'polar_to_cartesian',
-    'predict_source_position_in_camera',
-    'radec_to_camera',
-    'reco_source_position_sky',
-    'rotate',
-    'sky_to_camera',
-    'source_dx_dy',
-    'source_side',
+    "add_delta_t_key",
+    "alt_to_theta",
+    "az_to_phi",
+    "cal_cam_source_pos",
+    "camera_to_altaz",
+    "cartesian_to_polar",
+    "clip_alt",
+    "compute_alpha",
+    "compute_theta2",
+    "expand_tel_list",
+    "extract_source_position",
+    "filter_events",
+    "get_effective_time",
+    "get_event_pos_in_camera",
+    "impute_pointing",
+    "linear_imputer",
+    "polar_to_cartesian",
+    "predict_source_position_in_camera",
+    "radec_to_camera",
+    "reco_source_position_sky",
+    "rotate",
+    "sky_to_camera",
+    "source_dx_dy",
+    "source_side",
 ]
 
 # position of the LST1
 location = EarthLocation.from_geodetic(-17.89139 * u.deg, 28.76139 * u.deg, 2184 * u.m)
-obstime = Time('2018-11-01T02:00')
+obstime = Time("2018-11-01T02:00")
 horizon_frame = AltAz(location=location, obstime=obstime)
 
 
 log = logging.getLogger(__name__)
+
+
 def rotate(flat_object, degree=0, origin=(0, 0)):
     """
     Rotate 2D object around given axle
@@ -73,15 +75,23 @@ def rotate(flat_object, degree=0, origin=(0, 0)):
     NDArray with new coordinates
     """
     angle = np.deg2rad(degree)
-    rotation_matrix = np.array([[np.cos(angle), -np.sin(angle)],
-                                [np.sin(angle), np.cos(angle)]])
+    rotation_matrix = np.array(
+        [[np.cos(angle), -np.sin(angle)], [np.sin(angle), np.cos(angle)]]
+    )
     rotation_axis_coordinates = np.asarray(origin)
-    res = [(rotation_matrix @ (point.T-rotation_axis_coordinates.T) +
-                       rotation_axis_coordinates.T).T for point in np.atleast_2d(flat_object)]
+    res = [
+        (
+            rotation_matrix @ (point.T - rotation_axis_coordinates.T)
+            + rotation_axis_coordinates.T
+        ).T
+        for point in np.atleast_2d(flat_object)
+    ]
     return res
 
 
-def extract_source_position(data, observed_source_name, equivalent_focal_length = 28*u.m):
+def extract_source_position(
+    data, observed_source_name, equivalent_focal_length=28 * u.m
+):
     """
     Extract source position from data
 
@@ -96,11 +106,16 @@ def extract_source_position(data, observed_source_name, equivalent_focal_length
     2D array of coordinates of the source in form [(x),(y)] in astropy.units.m
     """
     observed_source = SkyCoord.from_name(observed_source_name)
-    obstime = pd.to_datetime(data['dragon_time'], unit='s')
-    pointing_alt = u.Quantity(data['alt_tel'], u.rad, copy=False)
-    pointing_az = u.Quantity(data['az_tel'], u.rad, copy=False)
-    source_pos_camera = radec_to_camera(observed_source, obstime,
-                                        pointing_alt, pointing_az, focal=equivalent_focal_length)
+    obstime = pd.to_datetime(data["dragon_time"], unit="s")
+    pointing_alt = u.Quantity(data["alt_tel"], u.rad, copy=False)
+    pointing_az = u.Quantity(data["az_tel"], u.rad, copy=False)
+    source_pos_camera = radec_to_camera(
+        observed_source,
+        obstime,
+        pointing_alt,
+        pointing_az,
+        focal=equivalent_focal_length,
+    )
     source_position = [source_pos_camera.x, source_pos_camera.y]
     return source_position
 
@@ -119,10 +134,11 @@ def compute_theta2(data, source_position, conversion_factor=2.0):
     -------
     Array with `theta2` values
     """
-    reco_src_x = np.array(data['reco_src_x']) * u.m
-    reco_src_y = np.array(data['reco_src_y']) * u.m
-    return conversion_factor**2 * ((source_position[0] - reco_src_x)**2 +
-                                   (source_position[1] - reco_src_y)**2)
+    reco_src_x = np.array(data["reco_src_x"]) * u.m
+    reco_src_y = np.array(data["reco_src_y"]) * u.m
+    return conversion_factor ** 2 * (
+        (source_position[0] - reco_src_x) ** 2 + (source_position[1] - reco_src_y) ** 2
+    )
 
 
 def compute_alpha(data):
@@ -138,7 +154,7 @@ def compute_alpha(data):
     Array with `alpha` values
     """
     # phi and psi range [-np.pi, +np.pi]
-    alpha = np.mod(data['phi'] - data['psi'], np.pi)  # alpha in [0, np.pi]
+    alpha = np.mod(data["phi"] - data["psi"], np.pi)  # alpha in [0, np.pi]
     alpha = np.minimum(np.pi - alpha, alpha)  # put alpha in [0, np.pi/2]
 
     return np.rad2deg(alpha)
@@ -175,7 +191,10 @@ def az_to_phi(az):
     return -az
 
 
-@deprecated("09/07/2019", message="This is a custom implementation. Use `sky_to_camera` that relies on astropy")
+@deprecated(
+    "09/07/2019",
+    message="This is a custom implementation. Use `sky_to_camera` that relies on astropy",
+)
 def cal_cam_source_pos(mc_alt, mc_az, mc_alt_tel, mc_az_tel, focal_length):
     """Transform Alt-Az source position into Camera(x,y) coordinates
     source position.
@@ -204,10 +223,10 @@ def cal_cam_source_pos(mc_alt, mc_az, mc_alt_tel, mc_az_tel, focal_length):
     float: source_x2
     """
 
-    mc_alt = alt_to_theta(mc_alt*u.rad).value
-    mc_az = az_to_phi(mc_az*u.rad).value
-    mc_alt_tel = alt_to_theta(mc_alt_tel*u.rad).value
-    mc_az_tel = az_to_phi(mc_az_tel*u.rad).value
+    mc_alt = alt_to_theta(mc_alt * u.rad).value
+    mc_az = az_to_phi(mc_az * u.rad).value
+    mc_alt_tel = alt_to_theta(mc_alt_tel * u.rad).value
+    mc_az_tel = az_to_phi(mc_az_tel * u.rad).value
 
     # Sines and cosines of direction angles
     cp = np.cos(mc_az)
@@ -216,8 +235,8 @@ def cal_cam_source_pos(mc_alt, mc_az, mc_alt_tel, mc_az_tel, focal_length):
     st = np.sin(mc_alt)
 
     # Shower direction coordinates
-    sourcex = st*cp
-    sourcey = st*sp
+    sourcex = st * cp
+    sourcey = st * sp
     sourcez = ct
 
     source = np.array([sourcex, sourcey, sourcez])
@@ -228,21 +247,29 @@ def cal_cam_source_pos(mc_alt, mc_az, mc_alt_tel, mc_az_tel, focal_length):
 
     alttel = mc_alt_tel
     aztel = mc_az_tel
-    mat_Y = np.array([[np.cos(alttel), 0, np.sin(alttel)],
-                      [0, 1, 0],
-                      [-np.sin(alttel), 0, np.cos(alttel)]]).T
+    mat_Y = np.array(
+        [
+            [np.cos(alttel), 0, np.sin(alttel)],
+            [0, 1, 0],
+            [-np.sin(alttel), 0, np.cos(alttel)],
+        ]
+    ).T
 
-    mat_Z = np.array([[np.cos(aztel), -np.sin(aztel), 0],
-                      [np.sin(aztel), np.cos(aztel), 0],
-                      [0, 0, 1]]).T
+    mat_Z = np.array(
+        [
+            [np.cos(aztel), -np.sin(aztel), 0],
+            [np.sin(aztel), np.cos(aztel), 0],
+            [0, 0, 1],
+        ]
+    ).T
 
     rot_Matrix = np.matmul(mat_Y, mat_Z)
 
     res = np.einsum("...ji,...i", rot_Matrix, source)
     res = res.T
 
-    source_x = -focal_length*res[0]/res[2]
-    source_y = -focal_length*res[1]/res[2]
+    source_x = -focal_length * res[0] / res[2]
+    source_y = -focal_length * res[1] / res[2]
     return source_x, source_y
 
 
@@ -259,24 +286,27 @@ def get_event_pos_in_camera(event, tel):
     (x, y) (float, float): position in the camera
     """
 
-    array_pointing = SkyCoord(alt=clip_alt(event.mcheader.run_array_direction[1]),
-                              az=event.mcheader.run_array_direction[0],
-                              frame=horizon_frame)
+    array_pointing = SkyCoord(
+        alt=clip_alt(event.mcheader.run_array_direction[1]),
+        az=event.mcheader.run_array_direction[0],
+        frame=horizon_frame,
+    )
 
-    event_direction = SkyCoord(alt=clip_alt(event.mc.alt),
-                               az=event.mc.az,
-                               frame=horizon_frame)
+    event_direction = SkyCoord(
+        alt=clip_alt(event.mc.alt), az=event.mc.az, frame=horizon_frame
+    )
 
     focal = tel.optics.equivalent_focal_length
 
-    camera_frame = CameraFrame(focal_length=focal,
-                               telescope_pointing=array_pointing)
+    camera_frame = CameraFrame(focal_length=focal, telescope_pointing=array_pointing)
 
     camera_pos = event_direction.transform_to(camera_frame)
     return camera_pos.x, camera_pos.y
 
 
-def reco_source_position_sky(cog_x, cog_y, disp_dx, disp_dy, focal_length, pointing_alt, pointing_az):
+def reco_source_position_sky(
+    cog_x, cog_y, disp_dx, disp_dy, focal_length, pointing_alt, pointing_az
+):
     """
     Compute the reconstructed source position in the sky
 
@@ -298,7 +328,7 @@ def reco_source_position_sky(cog_x, cog_y, disp_dx, disp_dy, focal_length, point
     return camera_to_altaz(src_x, src_y, focal_length, pointing_alt, pointing_az)
 
 
-def camera_to_altaz(pos_x, pos_y, focal, pointing_alt, pointing_az, obstime = None):
+def camera_to_altaz(pos_x, pos_y, focal, pointing_alt, pointing_az, obstime=None):
     """
     Compute camera to Horizontal frame (Altitude-Azimuth system). For MC assume the default ObsTime.
 
@@ -337,9 +367,13 @@ def camera_to_altaz(pos_x, pos_y, focal, pointing_alt, pointing_az, obstime = No
         logging.info("No time given. To be use only for MC data.")
     horizon_frame = AltAz(location=location, obstime=obstime)
 
-    pointing_direction = SkyCoord(alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame)
+    pointing_direction = SkyCoord(
+        alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame
+    )
 
-    camera_frame = CameraFrame(focal_length=focal, telescope_pointing=pointing_direction)
+    camera_frame = CameraFrame(
+        focal_length=focal, telescope_pointing=pointing_direction
+    )
 
     camera_coord = SkyCoord(pos_x, pos_y, frame=camera_frame)
 
@@ -363,9 +397,13 @@ def sky_to_camera(alt, az, focal, pointing_alt, pointing_az):
     -------
     camera frame: `astropy.coordinates.sky_coordinate.SkyCoord`
     """
-    pointing_direction = SkyCoord(alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame)
+    pointing_direction = SkyCoord(
+        alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame
+    )
 
-    camera_frame = CameraFrame(focal_length=focal, telescope_pointing=pointing_direction)
+    camera_frame = CameraFrame(
+        focal_length=focal, telescope_pointing=pointing_direction
+    )
 
     event_direction = SkyCoord(alt=clip_alt(alt), az=az, frame=horizon_frame)
 
@@ -373,6 +411,7 @@ def sky_to_camera(alt, az, focal, pointing_alt, pointing_az):
 
     return camera_pos
 
+
 def radec_to_camera(sky_coordinate, obstime, pointing_alt, pointing_az, focal):
     """
     Coordinate transform from sky coordinate to camera coordinates (x, y) in distance
@@ -383,22 +422,30 @@ def radec_to_camera(sky_coordinate, obstime, pointing_alt, pointing_az, focal):
     pointing_alt: pointing altitude in angle unit
     pointing_az: pointing altitude in angle unit
     focal: astropy Quantity
-    
+
     Returns
     -------
     camera frame: `astropy.coordinates.sky_coordinate.SkyCoord`
-    """   
-    
+    """
+
     horizon_frame = AltAz(location=location, obstime=obstime)
 
-    pointing_direction = SkyCoord(alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame)
+    pointing_direction = SkyCoord(
+        alt=clip_alt(pointing_alt), az=pointing_az, frame=horizon_frame
+    )
 
-    camera_frame = CameraFrame(focal_length=focal, telescope_pointing=pointing_direction, obstime=obstime, location=location)
+    camera_frame = CameraFrame(
+        focal_length=focal,
+        telescope_pointing=pointing_direction,
+        obstime=obstime,
+        location=location,
+    )
 
     camera_pos = sky_coordinate.transform_to(camera_frame)
 
     return camera_pos
 
+
 def source_side(source_pos_x, cog_x):
     """
     Compute on what side of the center of gravity the source is in the camera.
@@ -469,11 +516,11 @@ def cartesian_to_polar(x, y):
     -------
     norm, angle, sign
     """
-    norm = np.sqrt(x**2 + y**2)
+    norm = np.sqrt(x ** 2 + y ** 2)
     if x == 0:
-        angle = np.pi/2. * np.sign(y)
+        angle = np.pi / 2.0 * np.sign(y)
     else:
-        angle = np.arctan(y/x)
+        angle = np.arctan(y / x)
     sign = np.sign(x)
     return norm, angle, sign
 
@@ -509,54 +556,64 @@ def expand_tel_list(tel_list, max_tels):
     return pattern
 
 
-def filter_events(events,
-                  filters=dict(intensity=[0, np.inf],
-                               width=[0, np.inf],
-                               length=[0, np.inf],
-                               wl=[0, np.inf],
-                               r=[0, np.inf],
-                               leakage_intensity_width_2=[0, 1],
-                               ),
-                  finite_params=None,
-                  ):
+def filter_events(
+    events,
+    filters=dict(
+        intensity=[0, np.inf],
+        width=[0, np.inf],
+        length=[0, np.inf],
+        wl=[0, np.inf],
+        r=[0, np.inf],
+        leakage_intensity_width_2=[0, 1],
+    ),
+    finite_params=None,
+):
     """
-    Apply data filtering to a pandas dataframe.
+    Apply data filtering to a pandas dataframe or astropy Table.
+    The Table object will be converted to pandas dataframe and used.
     Each filtering range is applied if the column name exists in the DataFrame so that
     `(events >= range[0]) & (events <= range[1])`
+    Returning filter is converted to a numpy object so that it can be used by both dataframe
+    and table inputs
 
     Parameters
     ----------
-    events: `pandas.DataFrame`
+    events: `pandas.DataFrame` or 'astropy.table.Table'
     filters: dict containing events features names and their filtering range
     finite_params: optional, None or list of strings
         extra filter to ensure finite parameters
 
     Returns
     -------
-    `pandas.DataFrame`
+    `pandas.DataFrame` or 'astropy.table.Table'
     """
+    from astropy.table import Table
 
-    filter = np.ones(len(events), dtype=bool)
+    if isinstance(events, Table):
+        events_df = events.to_pandas()
+    else:
+        events_df = events
 
-    for k in filters.keys():
-        filter &= (events[k] >= filters[k][0]) & (events[k] <= filters[k][1])
+    filter = np.ones(len(events_df), dtype=bool)
+
+    for col, (lower_limit, upper_limit) in filters.items():
+        filter &= (events_df[col] >= lower_limit) & (events_df[col] <= upper_limit)
         
     if finite_params is not None:
-        _finite_params = list(set(finite_params).intersection(list(events.columns)))
+        _finite_params = list(set(finite_params).intersection(list(events_df.columns)))
         with pd.option_context('mode.use_inf_as_null', True):
-            not_finite_mask = events[_finite_params].isnull()
+            not_finite_mask = events_df[_finite_params].isnull()
         filter &= ~(not_finite_mask.any(axis=1))
 
         not_finite_counts = (not_finite_mask).sum(axis=0)[_finite_params]
         if (not_finite_counts > 0).any():
-            log.warning('Data contains not-predictable events.')
-            log.warning('Column | Number of non finite values')
+            log.warning("Data contains not-predictable events.")
+            log.warning("Column | Number of non finite values")
             for k, v in not_finite_counts.items():
                 if v > 0:
-                    log.warning(f'{k} : {v}')
-
-    return events[filter]
+                    log.warning(f"{k} : {v}")
 
+    return events[filter.to_numpy()]
 
 
 def linear_imputer(y, missing_values=np.nan, copy=True):
@@ -598,11 +655,13 @@ def impute_pointing(dl1_data, missing_values=np.nan):
         The placeholder for the missing values. All occurrences of `missing_values` will be imputed.
     """
     if len(set(dl1_data.event_id)) != len(dl1_data.event_id):
-        warn("Beware, the data has been resorted by `event_id` to interpolate invalid pointing values but there are "
-             "several events with the same `event_id` in the data, thus probably leading to unexpected behaviour",
-             UserWarning)
-    dl1_data = dl1_data.sort_values(by='event_id')
-    for k in ['alt_tel', 'az_tel']:
+        warn(
+            "Beware, the data has been resorted by `event_id` to interpolate invalid pointing values but there are "
+            "several events with the same `event_id` in the data, thus probably leading to unexpected behaviour",
+            UserWarning,
+        )
+    dl1_data = dl1_data.sort_values(by="event_id")
+    for k in ["alt_tel", "az_tel"]:
         dl1_data[k] = linear_imputer(dl1_data[k].values, missing_values=missing_values)
     return dl1_data
 
@@ -612,7 +671,8 @@ def clip_alt(alt):
     Make sure altitude is not larger than 90 deg (it happens in some MC files for zenith=0),
     to keep astropy happy
     """
-    return np.clip(alt, -90.*u.deg, 90.*u.deg)
+    return np.clip(alt, -90.0 * u.deg, 90.0 * u.deg)
+
 
 def add_delta_t_key(events):
     """
@@ -630,12 +690,13 @@ def add_delta_t_key(events):
     """
 
     # Get delta t of real data and add it to the data frame
-    if 'dragon_time' in events.columns:
-        time= np.array(events.dragon_time)
-        delta_t = np.insert(np.diff(time),0,0)
-        events['delta_t'] = delta_t
+    if "dragon_time" in events.columns:
+        time = np.array(events.dragon_time)
+        delta_t = np.insert(np.diff(time), 0, 0)
+        events["delta_t"] = delta_t
     return events
 
+
 def get_effective_time(events):
     """
     Calculate the effective observation time of a set of real data events
@@ -655,8 +716,8 @@ def get_effective_time(events):
     t_eff: astropy Quantity (in seconds, if input has no units)
     t_elapsed: astropy Quantity (ditto)
     """
-    timestamp = np.array(events['dragon_time'])
-    delta_t = np.array(events['delta_t'])
+    timestamp = np.array(events["dragon_time"])
+    delta_t = np.array(events["delta_t"])
 
     if not isinstance(timestamp, u.Quantity):
         timestamp *= u.s
@@ -670,11 +731,11 @@ def get_effective_time(events):
     # elapsed time: sum of those time differences, excluding large ones which
     # might indicate the DAQ was stopped (e.g. if the table contains more
     # than one run). We set 0.1 s as limit to decide a "break" occurred:
-    t_elapsed = np.sum(time_diff[time_diff<0.1*u.s])
+    t_elapsed = np.sum(time_diff[time_diff < 0.1 * u.s])
 
     # delta_t is the time elapsed since the previous triggered event.
     # We exclude the null values that might be set for the first even in a file.
-    delta_t = delta_t[delta_t>0.]
+    delta_t = delta_t[delta_t > 0.0 * u.s]
 
     # dead time per event (minimum observed delta_t, ):
     dead_time = np.amin(delta_t)
@@ -689,8 +750,8 @@ def get_effective_time(events):
     # events. But this truncation would hardly be noticeable for the typical
     # cosmics rates, and 200 Hz of interleaved events.
 
-    rate = 1/(np.mean(delta_t) - dead_time)
+    rate = 1 / (np.mean(delta_t) - dead_time)
 
-    t_eff = t_elapsed / (1 + rate*dead_time)
+    t_eff = t_elapsed / (1 + rate * dead_time)
 
     return t_eff, t_elapsed
