@@ -11,8 +11,7 @@ from ctapipe.core import Tool
 from ctapipe.io import EventSource
 from ctapipe.containers import PixelStatusContainer
 from lstchain.calib.camera.calibration_calculator import CalibrationCalculator
-from lstchain.calib.camera.r0 import CameraR0Calibrator
-from lstchain.io.lstcontainers import LSTEventType
+from ctapipe.containers import EventType
 
 __all__ = [
     'CalibrationHDF5Writer'
@@ -34,7 +33,6 @@ class CalibrationHDF5Writer(Tool):
     name = "CalibrationHDF5Writer"
     description = "Generate a HDF5 file with camera calibration coefficients"
 
-
     one_event = Bool(
         False,
         help='Stop after first calibration event'
@@ -45,36 +43,24 @@ class CalibrationHDF5Writer(Tool):
         help='Name of the output file'
     ).tag(config=True)
 
-    log_file = Unicode(
-        'None',
-        help='Name of the log file'
-    ).tag(config=True)
-
     calibration_product = traits.create_class_enum_trait(
        CalibrationCalculator,
         default_value='LSTCalibrationCalculator'
     )
 
-    r0calibrator_product =traits.create_class_enum_trait(
-        CameraR0Calibrator,
-        default_value='NullR0Calibrator'
-    )
-
     aliases = Dict(dict(
         input_file='EventSource.input_url',
-        output_file='CalibrationHDF5Writer.output_file',
-        log_file='CalibrationHDF5Writer.log_file',
         max_events='EventSource.max_events',
-        pedestal_file= 'LSTR0Corrections.pedestal_path',
+        output_file='CalibrationHDF5Writer.output_file',
         calibration_product='CalibrationHDF5Writer.calibration_product',
-        r0calibrator_product='CalibrationHDF5Writer.r0calibrator_product',
+
     ))
 
     classes = List([EventSource,
                     CalibrationCalculator
                     ]
-                   + traits.classes_with_traits(CameraR0Calibrator)
                    + traits.classes_with_traits(CalibrationCalculator)
+                   + traits.classes_with_traits(EventSource)
                    )
 
     def __init__(self, **kwargs):
@@ -89,9 +75,7 @@ class CalibrationHDF5Writer(Tool):
         """
         self.eventsource = None
         self.processor = None
-        self.container = None
         self.writer = None
-        self.r0calibrator = None
         self.tot_events = 0
         self.simulation = False
 
@@ -100,6 +84,10 @@ class CalibrationHDF5Writer(Tool):
         self.log.debug(f"Open  file")
         self.eventsource = EventSource.from_config(parent=self)
 
+        tel_id = self.eventsource.lst_service.telescope_id
+        if self.eventsource.r0_r1_calibrator.drs4_pedestal_path.tel[tel_id] is None:
+            raise IOError("Missing (mandatory) drs4 pedestal file in trailets")
+
         # if data remember how many event in the files
         if "LSTEventSource" in str(type(self.eventsource)):
             self.tot_events = len(self.eventsource.multi_file)
@@ -114,14 +102,7 @@ class CalibrationHDF5Writer(Tool):
             subarray = self.eventsource.subarray
         )
 
-        if self.r0calibrator_product:
-            self.r0calibrator = CameraR0Calibrator.from_name(
-                self.r0calibrator_product,
-                parent=self
-            )
-
-
-        group_name = 'tel_' + str(self.processor.tel_id)
+        group_name = 'tel_' + str(tel_id)
 
         self.log.debug(f"Open output file {self.output_file}")
 
@@ -132,7 +113,7 @@ class CalibrationHDF5Writer(Tool):
     def start(self):
         '''Calibration coefficient calculator'''
 
-        tel_id = self.processor.tel_id
+        tel_id = self.eventsource.lst_service.telescope_id
         new_ped = False
         new_ff = False
         end_of_file = False
@@ -142,9 +123,10 @@ class CalibrationHDF5Writer(Tool):
 
         try:
             self.log.debug(f"Start loop")
+            self.log.debug(f"If not simulation, skip first {events_to_skip} events")
             for count, event in enumerate(self.eventsource):
 
-                if count % 100 == 0:
+                if count % 100 == 0 and count> events_to_skip:
                     self.log.debug(f"Event {count}")
 
                 # if last event write results
@@ -172,34 +154,31 @@ class CalibrationHDF5Writer(Tool):
                     calib_data = event.mon.tel[tel_id].calibration
                     calib_data.meta['config'] = self.config
 
-                # correct for low level calibration
-                self.r0calibrator.calibrate(event)
 
                 # skip first events which are badly drs4 corrected
                 if not self.simulation and count < events_to_skip:
                     continue
 
-                # reject event without trigger type
-                if LSTEventType.is_unknown(event.r1.tel[tel_id].trigger_type):
-                    continue
-
                 # if pedestal event
-                if LSTEventType.is_pedestal(event.r1.tel[tel_id].trigger_type) or (
+                if event.trigger.event_type==EventType.SKY_PEDESTAL or (
                     self.simulation and
                     np.median(np.sum(event.r1.tel[tel_id].waveform[0], axis=1))
                     < self.processor.minimum_hg_charge_median):
+
+
                     new_ped = self.processor.pedestal.calculate_pedestals(event)
 
 
                 # if flat-field event: no calibration  TIB for the moment,
                 # use a cut on the charge for ff events and on std for rejecting Magic Lidar events
-                elif LSTEventType.is_calibration(event.r1.tel[tel_id].trigger_type) or (
-                        np.median(np.sum(event.r1.tel[tel_id].waveform[0], axis=1))
+                elif event.trigger.event_type==EventType.FLATFIELD or (
+                        self.simulation and np.median(np.sum(event.r1.tel[tel_id].waveform[0], axis=1))
                         > self.processor.minimum_hg_charge_median
                         and np.std(np.sum(event.r1.tel[tel_id].waveform[1], axis=1))
                         < self.processor.maximum_lg_charge_std):
 
-                    new_ff = self.processor.flatfield.calculate_relative_gain(event)
+                   new_ff = self.processor.flatfield.calculate_relative_gain(event)
+
                 # write pedestal results when enough statistics or end of file
                 if new_ped or end_of_file:
 
